@@ -260,6 +260,8 @@ def game_rink_map(data, good_team = None, title = None, strengths = ['all', '5v5
 
             colors_dict = {x: colors_dict[x] for x in order_list if x in colors_dict.keys()}
 
+            zorder_dict = {'GOAL': 3, 'SHOT': 2, 'MISS': 1}
+
             if team == good_team:
 
                 ax = ax1
@@ -284,8 +286,8 @@ def game_rink_map(data, good_team = None, title = None, strengths = ['all', '5v5
 
                     edge_color = None
 
-                rink.scatter(event_df.norm_coords_x, event_df.norm_coords_y, c = color, label = result,
-                           s = 250, alpha = 0.8, ax = ax, edgecolors = edge_color, is_constrained = True)
+                rink.scatter(event_df.norm_coords_x, event_df.norm_coords_y, c = color, label = result, s = 250, alpha = 0.8,
+                    ax = ax, edgecolors = edge_color, is_constrained = True zorder = zorder_dict[result])
 
                 
                 if result != 'GOAL':
